@@ -2,10 +2,12 @@ package Module::Install::Admin::Bundle;
 
 use strict;
 use Module::Install::Base;
+use Module::CoreList;
+use LWP::UserAgent;
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.95';;
+	$VERSION = '0.96';;
 	@ISA     = qw{Module::Install::Base};
 }
 
@@ -35,17 +37,22 @@ sub bundle {
 
     mkdir( $bundle_dir, 0777 );
 
-    my %bundles;
-
     while ( my ( $name, $version ) = splice( @_, 0, 2 ) ) {
         my $mod = $cp->module_tree($name);
-        next unless $mod;
+        if (not $mod) {
+            warn "Warning: Could not find distribution for module $name on CPAN. Bundle it manually.\n";
+            next;
+        }
+
         if ( $mod->package_is_perl_core or $self->{already_bundled}{$mod->package} ) {
-        	next;
+            next;
         }
 
         my $where = $mod->fetch( fetchdir => $bundle_dir, );
-        next unless ($where);
+        unless ($where) {
+            warn "Warning: Could not download distribution $bundle_dir. Download it manually.\n";
+            next;
+        }
         my $file = Cwd::abs_path($where);
 
         my $extract_result = $mod->extract(
@@ -54,24 +61,15 @@ sub bundle {
         );
 
         unlink $file;
-        next unless ($extract_result);
-        if ($extract_result =~ /$bundle_dir\/(.*)/) {
-            $bundles{$name} = 'inc/BUNDLES/'.$1;
-        } else {
-            $bundles{$name} = $extract_result;
+        unless ($extract_result) {
+            warn "Warning: Could not extract distribution $bundle_dir. Extract it manually.\n";
+            next;
         }
-        $self->{already_bundled}{ $mod->package }++;
 
+        $self->{already_bundled}{ $mod->package }++;
     }
 
     chdir $cwd;
-
-    local *FH;
-    open FH, ">> $bundle_dir.yml" or die "Cannot write to $bundle_dir.yml: $!";
-    foreach my $name ( sort keys %bundles ) {
-        print FH "$name: '$bundles{$name}'\n";
-    }
-    close FH;
 }
 
 1;
