@@ -1,15 +1,12 @@
 package Module::Install::Bundle;
 
 use strict;
-use Cwd                   ();
-use File::Find            ();
-use File::Copy            ();
-use File::Basename        ();
+use File::Spec;
 use Module::Install::Base ();
 
 use vars qw{$VERSION @ISA $ISCORE};
 BEGIN {
-	$VERSION = '0.95';
+	$VERSION = '0.96';
 	@ISA     = 'Module::Install::Base';
 	$ISCORE  = 1;
 }
@@ -17,6 +14,8 @@ BEGIN {
 sub auto_bundle {
     my $self = shift;
 
+    return $self->_install_bundled_dists unless $self->is_admin;
+
     # Flatten array of arrays into a single array
     my @core = map @$_, map @$_, grep ref, $self->requires;
 
@@ -25,75 +24,76 @@ sub auto_bundle {
 
 sub bundle {
     my $self = shift;
-    $self->admin->bundle(@_) if $self->is_admin;
 
-    my $cwd = Cwd::cwd();
-    my $bundles = $self->read_bundles;
-    my $bundle_dir = $self->_top->{bundle};
-    $bundle_dir =~ s/\W+/\\W+/g;
+    return $self->_install_bundled_dists unless $self->is_admin;
 
-    while (my ($name, $version) = splice(@_, 0, 2)) {
-        $version ||= 0;
-
-        my $source = $bundles->{$name} or die "Cannot find bundle source for $name";
-        my $target = File::Basename::basename($source);
-        $self->bundles($name, $target);
-
-        next if eval "use $name $version; 1";
-        mkdir( $target, 0777 ) or die $! unless -d $target;
-
-        # XXX - clean those directories upon "make clean"?
-        File::Find::find({
-            wanted => sub {
-                my $out = $_;
-                $out =~ s/$bundle_dir/./i;
-                mkdir( $out, 0777 ) if -d;
-                File::Copy::copy($_ => $out) unless -d;
-            },
-            no_chdir => 1,
-        }, $source);
-    }
-
-    chdir $cwd;
+    $self->admin->bundle(@_);
 }
 
-sub read_bundles {
-    my $self = shift;
-    my %map;
-
-    local *FH;
-    open FH, $self->_top->{bundle} . ".yml" or return {};
-    while (<FH>) {
-        /^(.*?): (['"])?(.*?)\2$/ or next;
-        $map{$1} = $3;
-    }
-    close FH;
-
-    return \%map;
-}
-
-
 sub auto_bundle_deps {
     my $self = shift;
 
+    return $self->_install_bundled_dists unless $self->is_admin;
+
     # Flatten array of arrays into a single array
     my @core = map @$_, map @$_, grep ref, $self->requires;
     while (my ($name, $version) = splice(@core, 0, 2)) {
         next unless $name;
          $self->bundle_deps($name, $version);
-         $self->bundle($name, $version);
     }
 }
 
 sub bundle_deps {
     my ($self, $pkg, $version) = @_;
-    my $deps = $self->admin->scan_dependencies($pkg) or return;
 
+    return $self->_install_bundled_dists unless $self->is_admin;
+
+    my $deps = $self->admin->scan_dependencies($pkg);
+    if (scalar keys %$deps == 0) {
+        # Probably a user trying to install the package, read the dependencies from META.yml
+        %$deps = ( map { $$_[0] => undef } (@{$self->requires()}) );
+    }
     foreach my $key (sort keys %$deps) {
         $self->bundle($key, ($key eq $pkg) ? $version : 0);
     }
 }
 
+sub _install_bundled_dists {
+    my $self = shift;
+
+    # process bundle only the first time this function is called
+    return if $self->{bundle_processed};
+
+    $self->makemaker_args->{DIR} ||= [];
+
+    # process all dists bundled in inc/BUNDLES/
+    my $bundle_dir = $self->_top->{bundle};
+    foreach my $sub_dir (glob File::Spec->catfile($bundle_dir,"*")) {
+
+        next if -f $sub_dir;
+
+        # ignore dot dirs/files if any
+        my $dot_file = File::Spec->catfile($bundle_dir,'\.');
+        next if index($sub_dir, $dot_file) >= $[;
+
+        # EU::MM can't handle Build.PL based distributions
+        if (-f File::Spec->catfile($sub_dir, 'Build.PL')) {
+            warn "Skipped: $sub_dir has Build.PL.";
+            next;
+        }
+
+        # EU::MM can't handle distributions without Makefile.PL
+        # (actually this is to cut blib in a wrong directory)
+        if (!-f File::Spec->catfile($sub_dir, 'Makefile.PL')) {
+            warn "Skipped: $sub_dir has no Makefile.PL.";
+            next;
+        }
+        push @{ $self->makemaker_args->{DIR} }, $sub_dir;
+    }
+
+    $self->{bundle_processed} = 1;
+}
+
 1;
 
 __END__
@@ -164,7 +164,7 @@ Same as C<bundle>, except that all dependencies of the bundled modules are
 also detected and bundled.  To use this function, you need to declare the
 minimum supported perl version first, like this:
 
-    requires( perl => 5.005 );
+    perl_version( '5.005' );
 
 =item * auto_bundle_deps
 
